@@ -161,11 +161,8 @@ class Payment(object):
             if capture_day <= 0:
                 raise ValueError("capture_date needs to be superior to the transaction date.")
 
-            kwargs['capture_day'] = capture_day
+            kwargs['capture_day'] = force_text(capture_day)
 
-        for param in kwargs:
-            # encode all input params to unicode
-            kwargs[param] = force_text(kwargs[param])
         return self.backend.request(amount, **kwargs)
 
     def response(self, query_string, **kwargs):
