@@ -496,7 +496,7 @@ class Payment(PaymentCommon):
         values = [u'%s=%s' % (a, b) for a, b in values if a in keep and b]
         tosign = key.join(values)
         tosign += key
-        tosign = force_byte(tosign)
+        tosign = force_byte(tosign, encoding='iso-8859-1')
         hashing = getattr(hashlib, algo)
         return hashing(tosign).hexdigest().upper()
 
