@@ -200,8 +200,11 @@ class Payment(PaymentCommon):
                 'name': 'platform',
                 'caption': _('Plateforme cible'),
                 'default': 'test',
-                'validation': lambda x: isinstance(x, six.string_types)
-                and x.lower() in ('test', 'prod'),
+                'choices': (
+                    ('test', 'Test'),
+                    ('backup', 'Backup'),
+                    ('prod', 'Production'),
+                )
             },
             {
                 'name': 'site',
@@ -232,9 +235,9 @@ class Payment(PaymentCommon):
             },
             {
                 'name': 'shared_secret',
-                'caption': _('Secret partagé'),
+                'caption': _('Secret partagé (clé HMAC)'),
                 'validation': lambda x: isinstance(x, str)
-                and all(a.lower() in '0123456789ABCDEF' for a in x),
+                and all(a.lower() in '0123456789abcdef' for a in x),
                 'required': True,
             },
             {
@@ -263,7 +266,7 @@ class Payment(PaymentCommon):
                 'caption': _('Capture Mode'),
                 'default': 'IMMEDIATE',
                 'required': False,
-                'choices': PAYMENT_MODES.keys()
+                'choices': list(PAYMENT_MODES)
             },
             {
                 'name': 'manual_validation',
