@@ -75,7 +75,7 @@ TEST_STATE = ('99',)
 
 
 def decrypt_ntkey(ntkey):
-    key = binascii.unhexlify(ntkey.replace(b' ', b''))
+    key = binascii.unhexlify(force_byte(ntkey).replace(b' ', b''))
     return decrypt_key(key)
 
 
