@@ -15,9 +15,11 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import base64
 import pytz
 import datetime as dt
 import hashlib
+import hmac
 import string
 from six.moves.urllib import parse as urlparse
 import warnings
@@ -242,6 +244,7 @@ class Payment(PaymentCommon):
 
     '''
     service_url = "https://paiement.systempay.fr/vads-payment/"
+    signature_algo = 'sha1'
 
     description = {
         'caption': 'SystemPay, système de paiment du groupe BPCE',
@@ -265,11 +268,18 @@ class Payment(PaymentCommon):
                 'required': True, },
             {'name': 'secret_test',
                 'caption': _(u'Secret pour la configuration de TEST'),
-                'validation': lambda value: str.isdigit(value),
+                'validation': lambda value: str.isalnum(value),
                 'required': True, },
             {'name': 'secret_production',
                 'caption': _(u'Secret pour la configuration de PRODUCTION'),
-                'validation': lambda value: str.isdigit(value), },
+                'validation': lambda value: str.isalnum(value), },
+            {'name': 'signature_algo',
+                'caption': _(u'Algorithme de signature'),
+                'default': 'sha1',
+                'choices': (
+                    ('sha1', 'SHA-1'),
+                    ('hmac_sha256', 'HMAC-SHA-256'),
+                )},
             {
                 'name': 'manual_validation',
                 'caption': 'Validation manuelle',
@@ -284,9 +294,15 @@ class Payment(PaymentCommon):
                  'vads_order_info2', 'vads_order_info3',
                  'vads_payment_cards', 'vads_payment_config', 'capture_day'):
         parameter = PARAMETER_MAP[name]
+
+        def check_value(parameter):
+            def validate(value):
+                return parameter.check_value(value)
+            return validate
+
         x = {'name': name,
              'caption': parameter.description or name,
-             'validation': lambda value: parameter.check_value(value),
+             'validation': check_value(parameter),
              'default': parameter.default,
              'required': parameter.needed,
              'help_text': parameter.help_text,
@@ -456,16 +472,24 @@ class Payment(PaymentCommon):
             test=test)
         return response
 
+    def sha1_sign(self, secret, signed_data):
+        return hashlib.sha1(signed_data).hexdigest()
+
+    def hmac_sha256_sign(self, secret, signed_data):
+        digest = hmac.HMAC(secret, digestmod=hashlib.sha256, msg=signed_data).digest()
+        return base64.b64encode(digest)
+
     def signature(self, fields):
         self.logger.debug('got fields %s to sign' % fields)
         ordered_keys = sorted(
             [key for key in fields.keys() if key.startswith('vads_')])
         self.logger.debug('ordered keys %s' % ordered_keys)
         ordered_fields = [force_byte(fields[key]) for key in ordered_keys]
-        secret = getattr(self, 'secret_%s' % fields['vads_ctx_mode'].lower())
+        secret = force_byte(getattr(self, 'secret_%s' % fields['vads_ctx_mode'].lower()))
         signed_data = b'+'.join(ordered_fields)
-        signed_data = b'%s+%s' % (signed_data, force_byte(secret))
+        signed_data = b'%s+%s' % (signed_data, secret)
         self.logger.debug(u'generating signature on «%s»', signed_data)
-        sign = hashlib.sha1(signed_data).hexdigest()
+        sign_method = getattr(self, '%s_sign' % self.signature_algo)
+        sign = sign_method(secret, signed_data)
         self.logger.debug(u'signature «%s»', sign)
-        return sign
+        return force_text(sign)
