@@ -85,7 +85,7 @@ class PayboxTests(TestCase):
         amount = '19.99'
         transaction_id, kind, what = backend.request(
             Decimal(amount), email=email, orderid=order_id,
-            transaction_id=transaction, time=time)
+            transaction_id=transaction, time=time, manual_validation=False)
         self.assertEqual(kind, eopayment.FORM)
         self.assertEqual(transaction_id, '1234')
         root = ET.fromstring(str(what))
@@ -155,7 +155,7 @@ class PayboxTests(TestCase):
         backend = eopayment.Payment('paybox', params)
         transaction_id, kind, what = backend.request(
             Decimal(amount), email=email, orderid=order_id,
-            transaction_id=transaction, time=time, capture_day=2)
+            transaction_id=transaction, time=time, capture_day='2')
         root = ET.fromstring(str(what))
 
         form_params = dict(((
@@ -171,7 +171,7 @@ class PayboxTests(TestCase):
         backend = eopayment.Payment('paybox', params)
         transaction_id, kind, what = backend.request(
             Decimal(amount), email=email, orderid=order_id,
-            transaction_id=transaction, time=time, capture_day=2)
+            transaction_id=transaction, time=time, capture_day='2')
         root = ET.fromstring(str(what))
 
         form_params = dict(((
