@@ -31,6 +31,7 @@ PARAMS = {
     'vads_site_id': u'12345678',
     'vads_ctx_mode': u'TEST',
     'vads_trans_date': u'20090501193530',
+    'signature_algo': 'sha1'
 }
 
 
@@ -80,6 +81,21 @@ def test_systempayv2():
     assert response.transaction_date
     assert response.transaction_date.isoformat() == '2020-03-30T16:25:30+00:00'
 
+    PARAMS['signature_algo'] = 'hmac_sha256'
+    p = Payment(PARAMS)
+    assert p.signature(qs) == 'aHrJ7IzSGFa4pcYA8kh99+M/xBzoQ4Odnu3f4BUrpIA='
+    response_qs = 'vads_amount=1042&vads_auth_mode=FULL&vads_auth_number=3feadf' \
+                  '&vads_auth_result=00&vads_capture_delay=0&vads_card_brand=CB' \
+                  '&vads_card_number=497010XXXXXX0000' \
+                  '&vads_payment_certificate=582ba2b725057618706d7a06e9e59acdbf69ff53' \
+                  '&vads_ctx_mode=TEST&vads_currency=978&vads_effective_amount=1042' \
+                  '&vads_site_id=70168983&vads_trans_date=20161013101355' \
+                  '&vads_trans_id=226787&vads_trans_uuid=4b5053b3b1fe4b02a07753e7a' \
+                  '&vads_effective_creation_date=20200330162530' \
+                  '&signature=PeU30M6ilqwhligBAIMQIR3yqxWFGZHJ8Hwtb%2B3IrOM%3D'
+    response = p.response(response_qs)
+    assert response.signed
+
     # bad response
     with pytest.raises(ResponseError, match='missing signature, vads_ctx_mode or vads_auth_result'):
         p.response('foo=bar')
@@ -143,3 +159,7 @@ def test_manual_validation():
     data['manual_validation'] = True
     transaction_id, f, form = backend.request(**data.copy())
     assert get_field(form, 'vads_validation_mode')['value'] == '1'
+
+    data['manual_validation'] = False
+    transaction_id, f, form = backend.request(**data.copy())
+    assert get_field(form, 'vads_validation_mode')['value'] == ''
