@@ -27,8 +27,8 @@ def test_tipi():
     p = eopayment.Payment('tipi', {'numcli': '12345'})
     payment_id, kind, url = p.request(
         amount=Decimal('123.12'),
-        exer=9999,
-        refdet=999900000000999999,
+        exer='9999',
+        refdet='999900000000999999',
         objet='tout a fait',
         email='info@entrouvert.com',
         urlcl='http://example.com/tipi/test',
